@@ -27,7 +27,7 @@ class ExperimentalDJ(DefaultDJ):
         ami = "ami-d47493bc"
         instance_type = "m3.xlarge"
         run_list = '{"run_list":["recipe[webslave::deploy_dj]"],"qubole_tier":"%s", "worker_name":"%s"}'
-        modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
+        modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "hive13", "hive2", "sqoop", "pig", "tapp2", "cloudman"]
         region = "us-east-1"
         az = "us-east-1b"
         security_groups = ['default']
